pub enum Dataset {
Senate,
Eleg,
Netwsc,
Hiv,
Dragon,
Circle {
n_points: usize,
},
Sphere {
n_points: usize,
},
Torus {
n_points: usize,
},
SwissRoll {
n_points: usize,
},
Uniform {
n_points: usize,
},
}Expand description
All datasets that we support.
Variants
Senate
The senate dataset from https://github.com/n-otter/PH-roadmap.
Eleg
The eleg dataset from https://github.com/n-otter/PH-roadmap.
Netwsc
The netwsc dataset from https://github.com/n-otter/PH-roadmap.
Hiv
The hiv dataset from https://github.com/n-otter/PH-roadmap.
Dragon
The dragon dataset from https://github.com/n-otter/PH-roadmap.
Circle
A circle in R^2.
Sphere
A noisy sphere in R^3.
Torus
A torus sphere in R^3.
SwissRoll
A swiss roll, that is, a plane rolled up in a spiral in R^3.
Uniform
Points sampled uniformly from a square in the plane.