pub enum Threshold {
KeepAll,
Percentile(f64),
Fixed(f64),
}Expand description
Possible thresholding settings.
Variants
KeepAll
Keep all edges.
Percentile(f64)
Restrict to the edges of length less than the given percentile of all distances.
Fixed(f64)
Restrict to the edges of length less that the given value.