EdgeList

Struct EdgeList 

pub struct EdgeList<E> {
    pub n_vertices: usize,
    /* private fields */
}
A graph represented as a list of edges, whose vertices are in the range 0..n_vertices. No self-loops are allowed.

Fields

n_vertices: usize

Total number of vertices.

Implementations

Source

impl<E: Edge> EdgeList<E>

pub fn new(n_vertices: usize) -> Self

New empty edge list.

pub fn edges(&self) -> &[E]

Returns the underlying slice of edges.

pub fn edges_mut(&mut self) -> &mut [E]

Returns a mutable slice of the underlying slice of edges.

pub fn len(&self) -> usize

Returns the number of edges.

pub fn is_empty(&self) -> bool

Returns whether there are edges.

pub fn from_iterator<I: Iterator<Item = E>>(it: I) -> Self

Collects all the edges from the given iterator.

pub fn number_of_vertices(&self) -> usize

Returns the number of vertices.

pub fn add_edge(&mut self, e: E)

Adds an edge to the graph. Panics: if the edge to add is a self-loop.

pub fn edge_iter(&self) -> impl Iterator<Item = &E> + '_

Returns an iterator over the edges.

pub fn degrees(&self) -> Vec<usize>

Returns a count of the degree of each vertex.

pub fn maximum_degree(&self) -> usize

Returns the maximum degree of a vertex in the edge list.

Source

impl<VF: Value, const N: usize> EdgeList<FilteredEdge<OneCriticalGrade<VF, N>>>

pub fn sort_lexicographically(&mut self)

Sort the filtered edges lexicographically in increasing order.

pub fn sort_reverse_lexicographically(&mut self)

Reverse sort the filtered edges lexicographically.

pub fn sort_colexicographically(&mut self)

Sort the filtered edges colexicographically in increasing order.

pub fn sort_reverse_colexicographically(&mut self)

Reverse sort the filtered edges colexicographically.

pub fn shuffle(&mut self)

Put a random order on the edges..