PointCloud

Struct PointCloud 

pub struct PointCloud<T: Float, const N: usize>(pub Vec<Point<T, N>>);
A collection of points.

Tuple Fields

0: Vec<Point<T, N>>

Implementations

Source

impl<T: Float, const N: usize> PointCloud<T, N>

pub fn new() -> Self

Create a new empty point cloud.

pub fn push_point(&mut self, p: Point<T, N>)

Add a new point.

pub fn distance_matrix(&self) -> DistanceMatrix<T>

Return the distance matrix of the point cloud, where the order is the order in which the points where added.

pub fn len(&self) -> usize

Returns the number of points in the point cloud.

pub fn is_empty(&self) -> bool

Returns whether the point cloud has no points.