pub enum EdgeOrder {
ReverseLexicographic,
Maintain,
}Expand description
The order in which we process the edges, and possibly remove them.
Variants
ReverseLexicographic
Go through the order in reverse lexicographic order. This is usually the fastest.
Maintain
Go through the edges in the order they currently have in the edge list.