pub struct PointCloud<T: Float, const N: usize>(pub Vec<Point<T, N>>);Expand description
A collection of points.
Tuple Fields
0: Vec<Point<T, N>>Implementations
Sourceimpl<T: Float, const N: usize> PointCloud<T, N>
impl<T: Float, const N: usize> PointCloud<T, N>
Sourcepub fn push_point(&mut self, p: Point<T, N>)
pub fn push_point(&mut self, p: Point<T, N>)
Add a new point.
Sourcepub fn distance_matrix(&self) -> DistanceMatrix<T>
pub fn distance_matrix(&self) -> DistanceMatrix<T>
Return the distance matrix of the point cloud, where the order is the order in which the points where added.